/**
 * Copyright (c) 2018-2022 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Adam Midlik <midlik@gmail.com>
 */
import { Color } from '../../mol-util/color';
export interface Metadata {
    grid: {
        general: {
            details: string;
        };
        volumes: Volumes;
        segmentation_lattices: SegmentationLattices;
        segmentation_meshes: SegmentationMeshes;
    };
    annotation: Annotation;
}
export interface Volumes {
    volume_downsamplings: number[];
    voxel_size: {
        [downsampling: number]: Vector3;
    };
    origin: Vector3;
    grid_dimensions: Vector3;
    sampled_grid_dimensions: {
        [downsampling: number]: Vector3;
    };
    mean: {
        [downsampling: number]: number;
    };
    std: {
        [downsampling: number]: number;
    };
    min: {
        [downsampling: number]: number;
    };
    max: {
        [downsampling: number]: number;
    };
    volume_force_dtype: string;
}
export interface SegmentationLattices {
    segmentation_lattice_ids: number[];
    segmentation_downsamplings: {
        [lattice: number]: number[];
    };
}
export interface Annotation {
    name: string;
    details: string;
    segment_list: Segment[];
}
export interface Segment {
    id: number;
    colour: number[];
    biological_annotation: BiologicalAnnotation;
}
export interface BiologicalAnnotation {
    name: string;
    external_references: {
        id: number;
        resource: string;
        accession: string;
        label: string;
        description: string;
    }[];
}
export interface SegmentationMeshes {
    mesh_component_numbers: {
        segment_ids?: {
            [segId: number]: {
                detail_lvls: {
                    [detail: number]: {
                        mesh_ids: {
                            [meshId: number]: {
                                num_triangles: number;
                                num_vertices: number;
                            };
                        };
                    };
                };
            };
        };
    };
    detail_lvl_to_fraction: {
        [lvl: number]: number;
    };
}
type Vector3 = [number, number, number];
export declare namespace Metadata {
    function meshSegments(metadata: Metadata): number[];
    function meshSegmentDetails(metadata: Metadata, segmentId: number): number[];
    /** Get the worst available detail level that is not worse than preferredDetail.
     * If preferredDetail is null, get the worst detail level overall.
     * (worse = greater number) */
    function getSufficientDetail(metadata: Metadata, segmentId: number, preferredDetail: number | null): number;
    function annotationsBySegment(metadata: Metadata): {
        [id: number]: Segment;
    };
    function dropSegments(metadata: Metadata, segments: number[]): void;
    function namesAndColorsBySegment(metadata: Metadata): {
        [id: number]: {
            name: string;
            color: Color;
        };
    };
}
export {};
