/**
 * Copyright (c) 2018-2022 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Adam Midlik <midlik@gmail.com>
 */
import { Color } from '../../mol-util/color';
export var Metadata;
(function (Metadata) {
    function meshSegments(metadata) {
        var segmentIds = metadata.grid.segmentation_meshes.mesh_component_numbers.segment_ids;
        if (segmentIds === undefined)
            return [];
        return Object.keys(segmentIds).map(function (s) { return parseInt(s); });
    }
    Metadata.meshSegments = meshSegments;
    function meshSegmentDetails(metadata, segmentId) {
        var segmentIds = metadata.grid.segmentation_meshes.mesh_component_numbers.segment_ids;
        if (segmentIds === undefined)
            return [];
        var details = segmentIds[segmentId].detail_lvls;
        return Object.keys(details).map(function (s) { return parseInt(s); });
    }
    Metadata.meshSegmentDetails = meshSegmentDetails;
    /** Get the worst available detail level that is not worse than preferredDetail.
     * If preferredDetail is null, get the worst detail level overall.
     * (worse = greater number) */
    function getSufficientDetail(metadata, segmentId, preferredDetail) {
        var availDetails = meshSegmentDetails(metadata, segmentId);
        if (preferredDetail !== null) {
            availDetails = availDetails.filter(function (det) { return det <= preferredDetail; });
        }
        return Math.max.apply(Math, availDetails);
    }
    Metadata.getSufficientDetail = getSufficientDetail;
    function annotationsBySegment(metadata) {
        var result = {};
        for (var _i = 0, _a = metadata.annotation.segment_list; _i < _a.length; _i++) {
            var segment = _a[_i];
            if (segment.id in result) {
                throw new Error("Duplicate segment annotation for segment ".concat(segment.id));
            }
            result[segment.id] = segment;
        }
        return result;
    }
    Metadata.annotationsBySegment = annotationsBySegment;
    function dropSegments(metadata, segments) {
        if (metadata.grid.segmentation_meshes.mesh_component_numbers.segment_ids === undefined)
            return;
        var dropSet = new Set(segments);
        metadata.annotation.segment_list = metadata.annotation.segment_list.filter(function (seg) { return !dropSet.has(seg.id); });
        for (var _i = 0, segments_1 = segments; _i < segments_1.length; _i++) {
            var seg = segments_1[_i];
            delete metadata.grid.segmentation_meshes.mesh_component_numbers.segment_ids[seg];
        }
    }
    Metadata.dropSegments = dropSegments;
    function namesAndColorsBySegment(metadata) {
        var result = {};
        for (var _i = 0, _a = metadata.annotation.segment_list; _i < _a.length; _i++) {
            var segment = _a[_i];
            if (segment.id in result)
                throw new Error("Duplicate segment annotation for segment ".concat(segment.id));
            result[segment.id] = { name: segment.biological_annotation.name, color: Color.fromNormalizedArray(segment.colour, 0) };
        }
        return result;
    }
    Metadata.namesAndColorsBySegment = namesAndColorsBySegment;
})(Metadata || (Metadata = {}));
